Base Class for Builders — suffix-tree 0.1.1 documentation

# Base Class for Builders

The base class for all builders.

class Builder

  The base class for all builders.

  __init__()
  build(root: Internal, id_: object, S: Iterable[Hashable]) → None

    Add the sequence to the tree.

  set_progress_function(tick: int, callback: Callable[[int], None] | None = None)

    Set a progress indicator callback function.

    You should not change the tree in this callback.

    Parameters:

      - tick (int) – call the callback every tick rounds

      - callback (Callable) – The function is called with the index of the current round as parameter.